# kssbox

## Introduction

JUST FOR TEST

## Usage

``` bash
pip install kssbox
# 更新
pip install -U kssbox
```

```python
from kssbox import main

print(main.add(1,2))
```

## 更新

``` bash
# 构建
python -m build

# 上传
python -m twine upload dist/*

```

## 文档

[Packaging Python Projects](https://packaging.python.org/en/latest/tutorials/packaging-projects/#creating-the-package-files)